@@ -22,7 +22,9 @@ var List = []list.Item{
 	CountCharacters{},
 	CountLines{},
 	CountWords{},
+	EscapeQuotes{},
 	ExtractEmails{},
+	ExtractURLs{},
 	ExtractIPs{},
 	FormatJSON{},
 	HexDecode{},
